@@ -739,9 +739,15 @@ void gnome_font_picker_font_extract_attr(gchar *font_name,
     gchar *pTmp;
 
     /* Search paramether */
-    for (pTmp=font_name; i!=0; i--,pTmp++)
-        pTmp=(gchar *)strchr(pTmp,'-');
+    if (*font_name != '\0') {
 
+        for (pTmp=font_name; i!=0; i--,pTmp++)
+	    pTmp=(gchar *)strchr(pTmp,'-');
+
+    } else {
+	pTmp = font_name;
+    }
+    
     if (*pTmp!=0) {
         while (*pTmp!='-' && *pTmp!=0) {
             *attr=*pTmp;
